var structspa__audio__info =
[
    [ "media_type", "structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30", null ],
    [ "media_subtype", "structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75", null ],
    [ "raw", "structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a", null ],
    [ "dsp", "structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410", null ],
    [ "iec958", "structspa__audio__info.html#aa02a98d24c25c529d6b387ed1eb7074e", null ],
    [ "dsd", "structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b", null ],
    [ "info", "structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3", null ]
];